%% FACS data analysis: scatter plots and histograms for YFP expression in liposomes.
% This program analyses FACS data for creating scatter plots and
% histograms.
% Steps for importing data:
    % Take the .fcs data from FACS instrument.
    % Import .fcs data into https://community.cytobank.org/
    % Filter the data accordingly (NO debris TX-red + NO debris dsGreen/YFP)
    % Export the filtered .fcs data as .txt files from https://community.cytobank.org/
        % Go to actions/export/export events/.txt file format/chose filter population to export/chose files to export/leave the channels as it is (all channels will be exported 
    % Save the .txt data in the same folder as this script is (the folder should also have importfile.m)

table{1}= importfile('B1.fcs_expCADGE_+dNTPs_3.txt'); 
table{2}= importfile('B4.fcs_expCADGE_-dNTPs_3.txt'); 
table{3}= importfile('B2.fcs_expCADGE_+dNTPs_4.txt'); 
table{4}= importfile('B11.fcs_expCADGE_-dNTPs_4.txt'); 
table{5}= importfile('B3.fcs_expCADGE_+dNTPs_5.txt');
table{6}= importfile('B10.water_2.txt'); 
table{7}= importfile('B12.fcs_expCADGE_-dNTPs_5.txt'); 
table{8}= importfile('B9.YFPonly_2.txt'); 

samples = ["expCADGE + dNTPs", "expCADGE - dNTPs", "expCADGE + dNTPs", "expCADGE + dNTPs", "oriYFP only", "water","expCADGE + dNTPs","expCADGE + dNTPs"]

set(groot,{'DefaultAxesXColor','DefaultAxesYColor','DefaultAxesZColor','DefaultAxesLineWidth'},{'k','k','k',1})
x = 1:100:10000000;
y = (x).^2;

% defining the water threshold
treshold=mean((table{6}.AlexaFluor488A)+(6*std(table{6}.AlexaFluor488A)))

YFP2=[];

for c = 1:8;
    YFP = [] %Expressed population (change the table{#} depending on the population to analyze)
for i = 1:length(table{c}.AlexaFluor488A)
    if table{c}.AlexaFluor488A(i) > treshold
        %&& table{1}.PETexasRedA(i) < mean((table{2}.PETexasRedA)+(2*std(table{2}.PETexasRedA)))
        YFP = [YFP; table{c}.AlexaFluor488A(i)];
    end
end

Per_YFP = (length(YFP)/length(table{c}.AlexaFluor488A))*100; %percentage of YFP expressing liposomes.
Per_YFP = round(Per_YFP,2) %round the percentage to only 2 decimals 
str = '' + string(Per_YFP) + {'%'} %conver to string for it to appear in the scatter plot.

%Scatter plots from FACS
f(c) = figure;
box on
set(gca,'FontSize',14);
h = get(gca, 'title');
set(h, 'FontSize',14)

scatter(table{c}.PETexasRedA, table{c}.AlexaFluor488A,7,'filled','MarkerFaceColor','#77AC30')
yline(treshold,'--k','LineWidth',2,'label',str,'fontsize',12)
set(gca,'xscale','log')
set(gca,'yscale','log')

xlim([10^2 10^6])
ylim([10^-0.5 10^6])
legend(samples(c),'background treshold','Location','NE','FontSize',12)
legend boxoff
xlabel('Membrane Dye Intensity')
ylabel('eYFP Intensity')
set(gca,'FontSize',14);
h = get(gca, 'title');
set(h, 'FontSize',14)
print(f(c),'-dpng','-r1000','PF1 flow cytometry')

YFP_cell{c}=YFP;
Per_YFP_cell{c}=Per_YFP

end

% f3 = figure; 
% histogram(YFP_cell{1},'BinWidth',100,'facecolor','#FF0000','FaceAlpha',0.1,'EdgeAlpha',1,'Normalization','count');
% hold on
% histogram(YFP_cell{3},'BinWidth',100,'facecolor','#0000FF','FaceAlpha',0.1,'EdgeAlpha',1,'Normalization','count');
% histogram(YFP_cell{5},'BinWidth',100,'facecolor','#00FFFF','FaceAlpha',0.1,'EdgeAlpha',1,'Normalization','count');
% xline(mean((table{6}.AlexaFluor488A)+(4*std(table{6}.AlexaFluor488A))),'--k','LineWidth',2,'fontsize',20)
% set(gca,'yscale','log')
% xlim([-500 11e3])
% legend('oriYFP "all expresed','oriYFP "all purified"','oriYFP only','Water Background Treshold','Location','NE','FontSize',12)
% legend boxoff
% xlabel('YFP intensity ','FontSize',14);
% ylabel('Log(count)','FontSize',14);
% set(gca,'fontsize',14)
% print(f3,'-dpng','-r1000','PF3 Histogram')
